local config = {}

-- Copy this file to `config.lua` before starting awesome.

-- To enable a module, add a line like the ones below.
-- To disable a module, delete its config table or set
-- enabled to false.

config.picom = { enabled = true }
config.lock = { enabled = true, type = "i3lock"}
config.battery = { enabled = false }
config.backlight = { enabled = false }
config.simple_widgets = { enabled = true }
config.launcher = { enabled = true }
config.screenshot = { enabled = true }
config.keymap_popup = { enabled = true }

config.core = {
	wallpaper = "/home/assets/wallpapers/Themed/Stellaris/Gigapixel/City.png",
	--
	-- Dynamic: a table of files and times
	-- {file = "path", start_time = {hour, minute}}
	--[[
	config.wallpaper = {
		{ file = "morning-file.png", start_time = {04, 00} },
		{ file = "noon-file.png", start_time = {11, 00} },
		{ file = "night-file.png", start_time = {19, 00} },
	}
	]]--

	-- The position of the bar on each screen
	bar_position = "bottom",
	-- Bar size in dpi
	bar_height = 50,
	-- Size of bar widget margins
	bar_margin = 3,

	-- Preferred terminal.
	terminal = "kitty",
	-- Preferred browser.
	browser = "firefox-developer-edition --new-tab",

	-- Table of layouts.
	-- This is not handled by the regular awesomewm facility.
	-- It's handled by layoutmanager, to add extra features.
	--
	-- This table is a table of tables.
	-- (see the example)
	-- the tables it contains are groups, switched through using the main
	-- layout keybind.
	--
	-- groups contain one or more layouts. The first layout is selected by default,
	-- and is used whenever that group is seleced.
	-- Likewise, the first group is the default, and is applied to all tags at the start.
	layouts = {
		{
			awful.layout.suit.tile.left,
			awful.layout.suit.tile,
		},
		{
			awful.layout.suit.fair,
			awful.layout.suit.fair.horizontal,
		},
		{
			awful.layout.suit.floating,
		}

		--awful.layout.suit.tile.bottom,
		--awful.layout.suit.tile.top,
		--awful.layout.suit.spiral,
		--awful.layout.suit.spiral.dwindle,
		--awful.layout.suit.max,
		--awful.layout.suit.max.fullscreen,
		--awful.layout.suit.magnifier,
		--awful.layout.suit.corner.nw,
		--awful.layout.suit.corner.ne,
		--awful.layout.suit.corner.sw,
		--awful.layout.suit.corner.se,
	},

	-- Run these commands, in this order, when awesome starts.
	startup_commands = {
		"ibus-daemon --daemonize --replace --xim",
		"keepassxc"
	},

	continuous_tag_updates = true,

	bar_shortcuts = {
		{
			"thunar",
			"folder"
		},
		{
			"firefox-developer-edition",
			"firefox_dev"
		},
		{
			"thunderbird",
			"thunderbird"
		},
		{
			"onlyoffice-desktopeditors",
			"writer"
		},
		{
			"signal-desktop",
			"signal"
		},
		{
			"keepassxc",
			"keepassx"
		}
	}

}

config.mpc = {
	enabled = true,

	-- If your MPC server has a password, do "passwd@host"
	host = "localhost",

	-- Fixed width of the mpc widget
	width = 250,
}



config.volume = {
	enabled = true,

	-- The pulse sink volume widgets and keybinds should use.
	--   To use the default, keep this value an empty string.
	--   Applies the --sink option to pamixer in wrapper.volume
	pamixer_sink = ""
}



config.ibus = {
	enabled = true,

	-- The first entry will be activated at startup.
	-- Use ibus engine to get the current engine name.
	-- DUPLICATE IBUS_ENGINE VALUES WILL BREAK THE SWITCHER!
	--
	-- Some overlay layours require a switch to en:us first.
	--  For example, switching from russian (xkb remap) to pinyin (ibus overlay on en:us)
	--  will not work. `requires_engine` fixes this.
	-- If it is defined, we will switch to that engine before switching to ibus_engine.
	language_list = {
		{
			title = "English",
			indicator_code = "en",
			ibus_engine = "xkb:us::eng",
		},
		{
			title = "LaTeX",
			indicator_code = "∫x",
			ibus_engine = "table:latex",
			requires_engine = "xkb:us::eng"
		},
		{
			title = "Russian",
			indicator_code = "ru",
			ibus_engine = "xkb:ru::rus"
		}
	}
}




return config
